pub struct SubagentNotifier {
notifications: UnboundedSender<Notification>,
subagent_id_counter: AtomicUsize,
}Expand description
Connects the subagent tool to a llimorse-chat app
New subagents registered with this will send the appropriate notifications to the UI and thus register themselves with it.
Fields
notifications: UnboundedSender<Notification>A notification channel to inform the llimorse-chat app of notifications
subagent_id_counter: AtomicUsizeA counter to auto-generate distinct subagent IDs
Implementations
Sourceimpl SubagentNotifier
impl SubagentNotifier
Sourcepub fn new(notifications: &NotificationChannel) -> Self
pub fn new(notifications: &NotificationChannel) -> Self
Create a new subagent notifier object for a llimorse-chat app.
New subagents registered with this will send the appropriate notifications over
notifications and thus register themselves with the UI.